@@ -4,6 +4,7 @@ namespace Mvc;
 use Epygi;
 use Epygi\Enum\Role as ERole;
 use Epygi\Selected;
+use Epygi\Help;
 use Mvc;
 use Mvc\Exception\PageNotFoundException;
 
@@ -226,6 +227,26 @@ class Router
         return false;
     }
 
+    public function getCgiByHelpRoot($helpRoot)
+    {
+        if(!empty($helpRoot)) {
+            foreach ($this->cgi_list as $cginame => $data) {
+                if(isset($data['condition']) && !$data['condition']) {
+                    continue;
+                }
+                if(!Help::hasHelp($cginame)) {
+                    continue;
+                }
+                $help_url = Help::getHelpUrl($cginame);
+                if(!empty($help_url) && $helpRoot === $help_url)
+                {
+                    return "/" . $cginame;
+                }
+            }
+        }
+        return "";
+    }
+
     private function getChildDeepSrc($child)
     {
         $route = $this->cgi_list[$child];
